@@ -47,21 +47,21 @@
 
 
 enum {
-	VALGRIND_SKIN_MEMCHECK,
-	VALGRIND_SKIN_ADDRCHECK,
-	VALGRIND_SKIN_CACHEGRIND,
-	VALGRIND_SKIN_HELGRIND,
+	VALGRIND_TOOL_MEMCHECK,
+	VALGRIND_TOOL_ADDRCHECK,
+	VALGRIND_TOOL_CACHEGRIND,
+	VALGRIND_TOOL_HELGRIND,
 };
 
 static struct {
 	const char *name;
-	int skin;
-} valgrind_skins[] = {
-	{ "memcheck",   VALGRIND_SKIN_MEMCHECK   },
-	{ "addrcheck",  VALGRIND_SKIN_ADDRCHECK  },
-	{ "cachegrind", VALGRIND_SKIN_CACHEGRIND },
-	{ "helgrind",   VALGRIND_SKIN_HELGRIND   },
-	{ NULL,         VALGRIND_SKIN_MEMCHECK   },
+	int tool;
+} valgrind_tools[] = {
+	{ "memcheck",   VALGRIND_TOOL_MEMCHECK   },
+	{ "addrcheck",  VALGRIND_TOOL_ADDRCHECK  },
+	{ "cachegrind", VALGRIND_TOOL_CACHEGRIND },
+	{ "helgrind",   VALGRIND_TOOL_HELGRIND   },
+	{ NULL,         VALGRIND_TOOL_MEMCHECK   },
 };
 
 static void alleyoop_class_init (AlleyoopClass *klass);
@@ -69,8 +69,8 @@ static void alleyoop_init (Alleyoop *alleyoop);
 static void alleyoop_destroy (GtkObject *obj);
 static void alleyoop_finalize (GObject *obj);
 
-static void tree_row_expanded (GtkTreeView *treeview, GtkTreeIter *root, GtkTreePath *path, gpointer user_data);
-static gboolean tree_button_press (GtkWidget *treeview, GdkEventButton *event, gpointer user_data);
+/*static void tree_row_expanded (GtkTreeView *treeview, GtkTreeIter *root, GtkTreePath *path, gpointer user_data);
+  static gboolean tree_button_press (GtkWidget *treeview, GdkEventButton *event, gpointer user_data);*/
 
 static gboolean io_ready_cb (GIOChannel *gio, GIOCondition condition, gpointer user_data);
 
@@ -274,7 +274,7 @@ open_ok_cb (GtkWidget *widget, gpointer user_data)
 	
 	if (filename != NULL) {
 		if ((fd = open (filename, O_RDONLY)) != -1) {
-			vg_skin_view_connect ((VgSkinView *) grind->view, fd);
+			vg_tool_view_connect ((VgToolView *) grind->view, fd);
 			
 			grind->pid = (pid_t) -1;
 			grind->gio = g_io_channel_unix_new (fd);
@@ -341,7 +341,7 @@ save_valgrind_log (Alleyoop *grind, const char *filename, int flags)
 	if ((fd = open (filename, flags, 0666)) != -1) {
 		int errnosav;
 		
-		if (vg_skin_view_save_log ((VgSkinView *) grind->view, fd) == -1) {
+		if (vg_tool_view_save_log ((VgToolView *) grind->view, fd) == -1) {
 			errnosav = errno;
 			close (fd);
 			unlink (filename);
@@ -451,7 +451,7 @@ edit_cut_cb (GtkWidget *widget, gpointer user_data)
 {
 	Alleyoop *grind = user_data;
 	
-	vg_skin_view_cut ((VgSkinView *) grind->view);
+	vg_tool_view_cut ((VgToolView *) grind->view);
 }
 
 static void
@@ -459,7 +459,7 @@ edit_copy_cb (GtkWidget *widget, gpointer user_data)
 {
 	Alleyoop *grind = user_data;
 	
-	vg_skin_view_copy ((VgSkinView *) grind->view);
+	vg_tool_view_copy ((VgToolView *) grind->view);
 }
 
 static void
@@ -467,7 +467,7 @@ edit_paste_cb (GtkWidget *widget, gpointer user_data)
 {
 	Alleyoop *grind = user_data;
 	
-	vg_skin_view_paste ((VgSkinView *) grind->view);
+	vg_tool_view_paste ((VgToolView *) grind->view);
 }
 
 static void
@@ -475,7 +475,7 @@ edit_clear_cb (GtkWidget *widget, gpointer user_data)
 {
 	Alleyoop *grind = user_data;
 	
-	vg_skin_view_clear ((VgSkinView *) grind->view);
+	vg_tool_view_clear ((VgToolView *) grind->view);
 }
 
 static void
@@ -491,39 +491,41 @@ edit_rules_cb (GtkWidget *widget, gpointer user_data)
 {
 	Alleyoop *grind = (Alleyoop *) user_data;
 	
-	vg_skin_view_show_rules ((VgSkinView *) grind->view);
+	vg_tool_view_show_rules ((VgToolView *) grind->view);
 }
 
 static void
-skins_default_cb (GtkWidget *widget, gpointer user_data)
+tools_default_cb (GtkWidget *widget, gpointer user_data)
 {
 	Alleyoop *grind = (Alleyoop *) user_data;
 	
-	grind->skin = NULL;
+	grind->tool = NULL;
 }
 
 static void
-skins_addrcheck_cb (GtkWidget *widget, gpointer user_data)
+tools_addrcheck_cb (GtkWidget *widget, gpointer user_data)
 {
 	Alleyoop *grind = (Alleyoop *) user_data;
 	
-	grind->skin = "addrcheck";
+	grind->tool = "addrcheck";
 }
 
+#if 0
 static void
-skins_cachegrind_cb (GtkWidget *widget, gpointer user_data)
+tools_cachegrind_cb (GtkWidget *widget, gpointer user_data)
 {
 	Alleyoop *grind = (Alleyoop *) user_data;
 	
-	grind->skin = "cachegrind";
+	grind->tool = "cachegrind";
 }
+#endif
 
 static void
-skins_helgrind_cb (GtkWidget *widget, gpointer user_data)
+tools_helgrind_cb (GtkWidget *widget, gpointer user_data)
 {
 	Alleyoop *grind = (Alleyoop *) user_data;
 	
-	grind->skin = "helgrind";
+	grind->tool = "helgrind";
 }
 
 static void
@@ -589,20 +591,20 @@ static GnomeUIInfo settings_menu[] = {
 	GNOMEUIINFO_END
 };
 
-static GnomeUIInfo skins_menu_items[] = {
-	{ GNOME_APP_UI_ITEM, "Memcheck", NULL, G_CALLBACK (skins_default_cb), NULL,
+static GnomeUIInfo tools_menu_items[] = {
+	{ GNOME_APP_UI_ITEM, "Memcheck", NULL, G_CALLBACK (tools_default_cb), NULL,
 	  NULL, GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, "Addrcheck", NULL, G_CALLBACK (skins_addrcheck_cb), NULL,
+	{ GNOME_APP_UI_ITEM, "Addrcheck", NULL, G_CALLBACK (tools_addrcheck_cb), NULL,
 	  NULL, GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
-	/*{ GNOME_APP_UI_ITEM, "Cachegrind", NULL, G_CALLBACK (skins_cachegrind_cb), NULL,
+	/*{ GNOME_APP_UI_ITEM, "Cachegrind", NULL, G_CALLBACK (tools_cachegrind_cb), NULL,
 	  NULL, GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },*/
-	{ GNOME_APP_UI_ITEM, "Helgrind", NULL, G_CALLBACK (skins_helgrind_cb), NULL,
+	{ GNOME_APP_UI_ITEM, "Helgrind", NULL, G_CALLBACK (tools_helgrind_cb), NULL,
 	  NULL, GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
 	GNOMEUIINFO_END
 };
 
-static GnomeUIInfo skins_menu[] = {
-	GNOMEUIINFO_RADIOLIST (skins_menu_items),
+static GnomeUIInfo tools_menu[] = {
+	GNOMEUIINFO_RADIOLIST (tools_menu_items),
 	GNOMEUIINFO_END
 };
 
@@ -615,7 +617,7 @@ static GnomeUIInfo alleyoop_menu[] = {
 	GNOMEUIINFO_MENU_FILE_TREE (file_menu),
 	GNOMEUIINFO_MENU_EDIT_TREE (edit_menu),
 	GNOMEUIINFO_MENU_SETTINGS_TREE (settings_menu),
-	GNOMEUIINFO_SUBTREE (N_("Skin"), skins_menu),
+	GNOMEUIINFO_SUBTREE (N_("Tool"), tools_menu),
 	GNOMEUIINFO_MENU_HELP_TREE (help_menu),
 	GNOMEUIINFO_END
 };
@@ -676,7 +678,7 @@ load_symtab (const char *progname)
 	SymTab *symtab;
 	char *filename;
 	
-	if (!(filename = vg_skin_view_scan_path (progname)))
+	if (!(filename = vg_tool_view_scan_path (progname)))
 		return NULL;
 	
 	symtab = symtab_new (filename);
@@ -686,7 +688,7 @@ load_symtab (const char *progname)
 }
 
 GtkWidget *
-alleyoop_new (const char *skin, const char **argv, const char **srcdir)
+alleyoop_new (const char *tool, const char **argv, const char **srcdir)
 {
 	GtkWidget *widget;
 	Alleyoop *grind;
@@ -705,7 +707,7 @@ alleyoop_new (const char *skin, const char **argv, const char **srcdir)
 	gnome_app_enable_layout_config ((GnomeApp *) grind, TRUE);
 	g_free (title);
 	
-	grind->skin = skin;
+	grind->tool = tool;
 	grind->argv = argv;
 	grind->srcdir = srcdir;
 	
@@ -715,12 +717,12 @@ alleyoop_new (const char *skin, const char **argv, const char **srcdir)
 	/* now construct the UI */
 	gnome_app_create_menus_with_data ((GnomeApp *) grind, alleyoop_menu, grind);
 	
-	if (skin != NULL) {
+	if (tool != NULL) {
 		widget = NULL;
 		
-		for (i = 0; valgrind_skins[i].name != NULL; i++) {
-			if (!strcmp (valgrind_skins[i].name, skin)) {
-				widget = skins_menu_items[i].widget;
+		for (i = 0; valgrind_tools[i].name != NULL; i++) {
+			if (!strcmp (valgrind_tools[i].name, tool)) {
+				widget = tools_menu_items[i].widget;
 				break;
 			}
 		}
@@ -735,9 +737,9 @@ alleyoop_new (const char *skin, const char **argv, const char **srcdir)
 	gtk_widget_set_sensitive (grind->toolbar_kill, FALSE);
 	
 	grind->view = widget = vg_default_view_new ();
-	vg_skin_view_set_argv ((VgSkinView *) widget, argv);
-	vg_skin_view_set_srcdir ((VgSkinView *) widget, srcdir);
-	vg_skin_view_set_symtab ((VgSkinView *) widget, grind->symtab);
+	vg_tool_view_set_argv ((VgToolView *) widget, argv);
+	vg_tool_view_set_srcdir ((VgToolView *) widget, srcdir);
+	vg_tool_view_set_symtab ((VgToolView *) widget, grind->symtab);
 	gtk_widget_show (widget);
 	gnome_app_set_contents ((GnomeApp *) grind, widget);
 	
@@ -754,7 +756,7 @@ io_ready_cb (GIOChannel *gio, GIOCondition condition, gpointer user_data)
 {
 	Alleyoop *grind = user_data;
 	
-	if ((condition & G_IO_IN) && vg_skin_view_step ((VgSkinView *) grind->view) <= 0) {
+	if ((condition & G_IO_IN) && vg_tool_view_step ((VgToolView *) grind->view) <= 0) {
 		alleyoop_kill (grind);
 		grind->watch_id = 0;
 		return FALSE;
@@ -787,7 +789,7 @@ alleyoop_run (Alleyoop *grind, GError **err)
 	if (pipe (logfd) == -1)
 		return;
 	
-	args = alleyoop_prefs_create_argv ((AlleyoopPrefs *) grind->prefs, grind->skin);
+	args = alleyoop_prefs_create_argv ((AlleyoopPrefs *) grind->prefs, grind->tool);
 	
 	sprintf (logfd_arg, "--logfile-fd=%d", logfd[1]);
 	g_ptr_array_add (args, logfd_arg);
@@ -797,7 +799,6 @@ alleyoop_run (Alleyoop *grind, GError **err)
 	g_ptr_array_add (args, NULL);
 	
 	argv = (char **) args->pdata;
-	g_ptr_array_free (args, FALSE);
 	
 	grind->pid = process_fork (argv[0], argv, TRUE, logfd[1], NULL, NULL, NULL, err);
 	if (grind->pid == (pid_t) -1) {
@@ -806,9 +807,11 @@ alleyoop_run (Alleyoop *grind, GError **err)
 		return;
 	}
 	
+	g_ptr_array_free (args, TRUE);
+	
 	close (logfd[1]);
 	
-	vg_skin_view_connect ((VgSkinView *) grind->view, logfd[0]);
+	vg_tool_view_connect ((VgToolView *) grind->view, logfd[0]);
 	
 	grind->gio = g_io_channel_unix_new (logfd[0]);
 	grind->watch_id = g_io_add_watch (grind->gio, G_IO_IN | G_IO_HUP, io_ready_cb, grind);
@@ -821,7 +824,7 @@ alleyoop_run (Alleyoop *grind, GError **err)
 void
 alleyoop_kill (Alleyoop *grind)
 {
-	vg_skin_view_disconnect ((VgSkinView *) grind->view);
+	vg_tool_view_disconnect ((VgToolView *) grind->view);
 	
 	if (grind->gio) {
 		g_io_channel_close (grind->gio);
