@@ -77,16 +77,16 @@ static void vg_default_view_init (VgDefaultView *view);
 static void vg_default_view_destroy (GtkObject *obj);
 static void vg_default_view_finalize (GObject *obj);
 
-static void valgrind_view_clear (VgSkinView *skin);
-static void valgrind_view_reset (VgSkinView *skin);
-static void valgrind_view_connect (VgSkinView *skin, int sockfd);
-static int  valgrind_view_step (VgSkinView *skin);
-static void valgrind_view_disconnect (VgSkinView *skin);
-static int  valgrind_view_save_log (VgSkinView *skin, int fd);
-static void valgrind_view_cut (VgSkinView *skin);
-static void valgrind_view_copy (VgSkinView *skin);
-static void valgrind_view_paste (VgSkinView *skin);
-static void valgrind_view_show_rules (VgSkinView *skin);
+static void valgrind_view_clear (VgToolView *tool);
+static void valgrind_view_reset (VgToolView *tool);
+static void valgrind_view_connect (VgToolView *tool, int sockfd);
+static int  valgrind_view_step (VgToolView *tool);
+static void valgrind_view_disconnect (VgToolView *tool);
+static int  valgrind_view_save_log (VgToolView *tool, int fd);
+static void valgrind_view_cut (VgToolView *tool);
+static void valgrind_view_copy (VgToolView *tool);
+static void valgrind_view_paste (VgToolView *tool);
+static void valgrind_view_show_rules (VgToolView *tool);
 
 static void rule_added (VgRuleList *list, VgRule *rule, gpointer user_data);
 static void tree_row_expanded (GtkTreeView *treeview, GtkTreeIter *root, GtkTreePath *path, gpointer user_data);
@@ -96,7 +96,7 @@ static void view_show_error (VgDefaultView *view, GtkTreeStore *model, VgError *
 static void view_rebuild (VgDefaultView *view);
 
 
-static VgSkinViewClass *parent_class = NULL;
+static VgToolViewClass *parent_class = NULL;
 
 
 GType
@@ -117,7 +117,7 @@ vg_default_view_get_type (void)
 			(GInstanceInitFunc) vg_default_view_init,
 		};
 		
-		type = g_type_register_static (VG_TYPE_SKIN_VIEW, "VgDefaultView", &info, 0);
+		type = g_type_register_static (VG_TYPE_TOOL_VIEW, "VgDefaultView", &info, 0);
 	}
 	
 	return type;
@@ -128,24 +128,24 @@ vg_default_view_class_init (VgDefaultViewClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GtkObjectClass *gtk_object_class = GTK_OBJECT_CLASS (klass);
-	VgSkinViewClass *skin_class = VG_SKIN_VIEW_CLASS (klass);
+	VgToolViewClass *tool_class = VG_TOOL_VIEW_CLASS (klass);
 	
-	parent_class = g_type_class_ref (VG_TYPE_SKIN_VIEW);
+	parent_class = g_type_class_ref (VG_TYPE_TOOL_VIEW);
 	
 	object_class->finalize = vg_default_view_finalize;
 	gtk_object_class->destroy = vg_default_view_destroy;
 	
 	/* virtual methods */
-	skin_class->clear = valgrind_view_clear;
-	skin_class->reset = valgrind_view_reset;
-	skin_class->connect = valgrind_view_connect;
-	skin_class->step = valgrind_view_step;
-	skin_class->disconnect = valgrind_view_disconnect;
-	skin_class->save_log = valgrind_view_save_log;
-	skin_class->cut = valgrind_view_cut;
-	skin_class->copy = valgrind_view_copy;
-	skin_class->paste = valgrind_view_paste;
-	skin_class->show_rules = valgrind_view_show_rules;
+	tool_class->clear = valgrind_view_clear;
+	tool_class->reset = valgrind_view_reset;
+	tool_class->connect = valgrind_view_connect;
+	tool_class->step = valgrind_view_step;
+	tool_class->disconnect = valgrind_view_disconnect;
+	tool_class->save_log = valgrind_view_save_log;
+	tool_class->cut = valgrind_view_cut;
+	tool_class->copy = valgrind_view_copy;
+	tool_class->paste = valgrind_view_paste;
+	tool_class->show_rules = valgrind_view_show_rules;
 }
 
 
@@ -249,11 +249,9 @@ search_bar_clear (VgSearchBar *bar, VgDefaultView *view)
 static void
 vg_default_view_init (VgDefaultView *view)
 {
-	VgSkinView *skin = (VgSkinView *) view;
 	GtkWidget *scrolled;
 	GtkWidget *search;
 	char *filename;
-	int i;
 	
 	view->suppressions = g_ptr_array_new ();
 	view->errors = g_ptr_array_new ();
@@ -352,9 +350,9 @@ vg_default_view_destroy (GtkObject *obj)
 
 
 static void
-valgrind_view_clear (VgSkinView *skin)
+valgrind_view_clear (VgToolView *tool)
 {
-	VgDefaultView *view = (VgDefaultView *) skin;
+	VgDefaultView *view = (VgDefaultView *) tool;
 	GtkTreeStore *model;
 	int i;
 	
@@ -368,7 +366,7 @@ valgrind_view_clear (VgSkinView *skin)
 }
 
 static void
-valgrind_view_reset (VgSkinView *skin)
+valgrind_view_reset (VgToolView *tool)
 {
 	;
 }
@@ -377,10 +375,10 @@ valgrind_view_reset (VgSkinView *skin)
 static void
 valgrind_init_src_preview (VgDefaultView *view, GtkTreeStore *model, GtkTreeIter *root, VgErrorStack *stack)
 {
-	VgSkinView *skin = (VgSkinView *) view;
+	VgToolView *tool = (VgToolView *) view;
 	GtkTreeIter iter;
 	
-	if (!skin->symtab && !skin->srcdir)
+	if (!tool->symtab && !tool->srcdir)
 		return;
 	
 	gtk_tree_store_append (model, &iter, root);
@@ -476,7 +474,6 @@ view_show_error (VgDefaultView *view, GtkTreeStore *model, VgError *err)
 static gboolean
 error_matches_search (VgError *err, int search_id, regex_t *regex)
 {
-	gboolean matches = FALSE;
 	VgErrorSummary *summary;
 	VgErrorStack *stack;
 	
@@ -565,20 +562,20 @@ recv_error_cb (VgErrorParser *parser, VgError *err, gpointer user_data)
 }
 
 static void
-valgrind_view_connect (VgSkinView *skin, int sockfd)
+valgrind_view_connect (VgToolView *tool, int sockfd)
 {
-	VgDefaultView *view = (VgDefaultView *) skin;
+	VgDefaultView *view = (VgDefaultView *) tool;
 	
 	if (view->parser != NULL)
-		valgrind_view_disconnect (skin);
+		valgrind_view_disconnect (tool);
 	
 	view->parser = vg_error_parser_new (sockfd, recv_error_cb, view);
 }
 
 static int
-valgrind_view_step (VgSkinView *skin)
+valgrind_view_step (VgToolView *tool)
 {
-	VgDefaultView *view = (VgDefaultView *) skin;
+	VgDefaultView *view = (VgDefaultView *) tool;
 	
 	g_return_val_if_fail (view->parser != NULL, -1);
 	
@@ -586,9 +583,9 @@ valgrind_view_step (VgSkinView *skin)
 }
 
 static void
-valgrind_view_disconnect (VgSkinView *skin)
+valgrind_view_disconnect (VgToolView *tool)
 {
-	VgDefaultView *view = (VgDefaultView *) skin;
+	VgDefaultView *view = (VgDefaultView *) tool;
 	int i;
 	
 	if (view->parser) {
@@ -607,9 +604,9 @@ valgrind_view_disconnect (VgSkinView *skin)
 
 
 static int
-valgrind_view_save_log (VgSkinView *skin, int fd)
+valgrind_view_save_log (VgToolView *tool, int fd)
 {
-	VgDefaultView *view = (VgDefaultView *) skin;
+	VgDefaultView *view = (VgDefaultView *) tool;
 	VgError *err;
 	GString *str;
 	int i;
@@ -636,15 +633,15 @@ valgrind_view_save_log (VgSkinView *skin, int fd)
 }
 
 static void
-valgrind_view_cut (VgSkinView *skin)
+valgrind_view_cut (VgToolView *tool)
 {
-	valgrind_view_copy (skin);
+	valgrind_view_copy (tool);
 }
 
 static void
-valgrind_view_copy (VgSkinView *skin)
+valgrind_view_copy (VgToolView *tool)
 {
-	VgDefaultView *view = (VgDefaultView *) skin;
+	VgDefaultView *view = (VgDefaultView *) tool;
 	GtkTreeSelection *selection;
 	GtkClipboard *clipboard;
 	VgErrorSummary *summary;
@@ -668,7 +665,7 @@ valgrind_view_copy (VgSkinView *skin)
 }
 
 static void
-valgrind_view_paste (VgSkinView *skin)
+valgrind_view_paste (VgToolView *tool)
 {
 	;
 }
@@ -693,14 +690,14 @@ rules_delete_event_cb (GtkWidget *widget, gpointer user_data)
 }
 
 static void
-valgrind_view_show_rules (VgSkinView *skin)
+valgrind_view_show_rules (VgToolView *tool)
 {
-	VgDefaultView *view = (VgDefaultView *) skin;
+	VgDefaultView *view = (VgDefaultView *) tool;
 	GtkWidget *dialog;
 	GtkWidget *parent;
 	
-	if (skin->rules == NULL) {
-		parent = gtk_widget_get_toplevel ((GtkWidget *) skin);
+	if (tool->rules == NULL) {
+		parent = gtk_widget_get_toplevel ((GtkWidget *) tool);
 		parent = GTK_WIDGET_TOPLEVEL (parent) ? parent : NULL;
 		
 		/* FIXME: we should really get this title from somewhere else? */
@@ -723,10 +720,10 @@ valgrind_view_show_rules (VgSkinView *skin)
 		g_signal_connect (dialog, "response", G_CALLBACK (rules_response_cb), view);
 		g_signal_connect (dialog, "delete-event", G_CALLBACK (rules_delete_event_cb), view);
 		
-		skin->rules = dialog;
+		tool->rules = dialog;
 	}
 	
-	VG_SKIN_VIEW_CLASS (parent_class)->show_rules (skin);
+	VG_TOOL_VIEW_CLASS (parent_class)->show_rules (tool);
 }
 
 
@@ -878,7 +875,7 @@ str_ends_with (const char *str, const char *match)
 }
 
 static char *
-resolve_full_path (VgSkinView *skin, VgErrorStack *stack)
+resolve_full_path (VgToolView *tool, VgErrorStack *stack)
 {
 	const char *filename;
 	SymTabSymbol *sym;
@@ -890,7 +887,7 @@ resolve_full_path (VgSkinView *skin, VgErrorStack *stack)
 	if (*filename == '/')
 		return g_strdup (filename);
 	
-	if (skin->symtab && (sym = symtab_resolve_addr (skin->symtab, (void *) stack->addr, FALSE))) {
+	if (tool->symtab && (sym = symtab_resolve_addr (tool->symtab, (void *) stack->addr, FALSE))) {
 		if (sym->filename != NULL) {
 			if (*sym->filename == '/' && str_ends_with (sym->filename, filename)) {
 				path = g_strdup (sym->filename);
@@ -904,7 +901,7 @@ resolve_full_path (VgSkinView *skin, VgErrorStack *stack)
 		symtab_symbol_free (sym);
 	}
 	
-	if (skin->srcdir) {
+	if (tool->srcdir) {
 		unsigned int buflen;
 		const char *dir;
 		struct stat st;
@@ -917,8 +914,8 @@ resolve_full_path (VgSkinView *skin, VgErrorStack *stack)
 		
 		flen = strlen (filename);
 		
-		for (i = 0; skin->srcdir[i] != NULL; i++) {
-			dir = skin->srcdir[i];
+		for (i = 0; tool->srcdir[i] != NULL; i++) {
+			dir = tool->srcdir[i];
 			dlen = strlen (dir);
 			
 			if (dlen + flen + 2 > buflen) {
@@ -935,7 +932,7 @@ resolve_full_path (VgSkinView *skin, VgErrorStack *stack)
 				break;
 		}
 		
-		if (skin->srcdir[i] != NULL && S_ISREG (st.st_mode))
+		if (tool->srcdir[i] != NULL && S_ISREG (st.st_mode))
 			return path;
 		
 		g_free (path);
@@ -945,7 +942,7 @@ resolve_full_path (VgSkinView *skin, VgErrorStack *stack)
 }
 
 static char *
-load_src_buf (VgSkinView *skin, VgErrorStack *stack, int srclines)
+load_src_buf (VgToolView *tool, VgErrorStack *stack, int srclines)
 {
 	char *path, *srcbuf;
 	size_t lineno;
@@ -954,7 +951,7 @@ load_src_buf (VgSkinView *skin, VgErrorStack *stack, int srclines)
 	lineno = stack->info.src.lineno;
 	first = lineno > (srclines + 1) ? lineno - srclines : 1;
 	
-	if (!(path = resolve_full_path (skin, stack)))
+	if (!(path = resolve_full_path (tool, stack)))
 		return NULL;
 	
 	srcbuf = read_src_lines (path, first, lineno + srclines, lineno);
@@ -967,7 +964,7 @@ static void
 tree_row_expanded (GtkTreeView *treeview, GtkTreeIter *parent, GtkTreePath *path, gpointer user_data)
 {
 	VgDefaultView *view = user_data;
-	VgSkinView *skin = user_data;
+	VgToolView *tool = user_data;
 	VgErrorStack *stack = NULL;
 	GtkTreeStore *model;
 	GtkTreeIter iter;
@@ -988,7 +985,7 @@ tree_row_expanded (GtkTreeView *treeview, GtkTreeIter *parent, GtkTreePath *path
 	
 	gtk_tree_model_get ((GtkTreeModel *) model, &iter, COL_POINTER_STACK, &stack, -1);
 	
-	if (!(srcbuf = load_src_buf (skin, stack, view->srclines))) {
+	if (!(srcbuf = load_src_buf (tool, stack, view->srclines))) {
 		w(g_warning ("couldn't load src preview"));
 		gtk_tree_store_remove (model, &iter);
 		return;
@@ -1010,17 +1007,17 @@ tree_row_expanded (GtkTreeView *treeview, GtkTreeIter *parent, GtkTreePath *path
 static void
 cut_cb (GtkWidget *widget, gpointer user_data)
 {
-	VgSkinView *skin = user_data;
+	VgToolView *tool = user_data;
 	
-	valgrind_view_cut (skin);
+	valgrind_view_cut (tool);
 }
 
 static void
 copy_cb (GtkWidget *widget, gpointer user_data)
 {
-	VgSkinView *skin = user_data;
+	VgToolView *tool = user_data;
 	
-	valgrind_view_copy (skin);
+	valgrind_view_copy (tool);
 }
 
 static void
@@ -1068,7 +1065,7 @@ spawn_editor (VgDefaultView *view, const char *editor)
 	if (stack == NULL)
 		return;
 	
-	if (!(path = resolve_full_path ((VgSkinView *) view, stack)))
+	if (!(path = resolve_full_path ((VgToolView *) view, stack)))
 		return;
 	
 	lineno = g_strdup_printf ("+%u", stack->info.src.lineno);
@@ -1105,7 +1102,7 @@ emacs_cb (GtkWidget *widget, gpointer user_data)
 	if (stack == NULL)
 		return;
 	
-	if (!(path = resolve_full_path ((VgSkinView *) view, stack)))
+	if (!(path = resolve_full_path ((VgToolView *) view, stack)))
 		return;
 	
 	lineno = g_strdup_printf ("+%u", stack->info.src.lineno);
@@ -1164,7 +1161,7 @@ custom_editor_cb (GtkWidget *widget, gpointer user_data)
 	if (stack == NULL)
 		return;
 	
-	if (!(path = resolve_full_path ((VgSkinView *) view, stack)))
+	if (!(path = resolve_full_path ((VgToolView *) view, stack)))
 		return;
 	
 	if (!(var = gconf_client_get_string (view->gconf, CUSTOM_EDITOR_KEY, NULL))) {
